--- src/parser/attack_parser.y	(revision 238)
+++ src/parser/attack_parser.y	(working copy)
@@ -93,6 +93,8 @@
 %token SSH_NOIDENTIFSTR SSH_BADPROTOCOLIDENTIF
 /* dovecot */
 %token DOVECOT_IMAP_LOGINERR_PREF DOVECOT_IMAP_LOGINERR_SUFF
+/* postfix */
+%token POSTFIX_SASL_LOGINERR_PREF POSTFIX_SASL_LOGINERR_SUFF
 /* uwimap */
 %token UWIMAP_LOGINERR
 /* cyrus-imap */
@@ -168,6 +170,7 @@
 msg_single:
     sshmsg              {   parsed_attack.service = SERVICES_SSH; }
     | dovecotmsg        {   parsed_attack.service = SERVICES_DOVECOT; }
+    | postfixmsg        {   parsed_attack.service = SERVICES_POSTFIX; }
     | uwimapmsg         {   parsed_attack.service = SERVICES_UWIMAP; }
     | cyrusimapmsg      {   parsed_attack.service = SERVICES_CYRUSIMAP; }
     | cucipopmsg        {   parsed_attack.service = SERVICES_CUCIPOP; }
@@ -296,6 +299,10 @@
     DOVECOT_IMAP_LOGINERR_PREF addr DOVECOT_IMAP_LOGINERR_SUFF
     ;
 
+postfixmsg:
+    POSTFIX_SASL_LOGINERR_PREF addr POSTFIX_SASL_LOGINERR_SUFF
+    ;
+
 /* attack rules for UWIMAP */
 uwimapmsg:
     UWIMAP_LOGINERR '[' addr ']'
--- src/parser/attack_scanner.l	(revision 238)
+++ src/parser/attack_scanner.l	(working copy)
@@ -66,7 +66,7 @@
  /* for Login services */
 %s ssh_notallowed ssh_loginerr ssh_reversemap
  /* for Mail services */
-%s dovecot_loginerr  cyrusimap_loginerr exim_esmtp_autherr sendmail_relaydenied
+%s dovecot_loginerr postfix_loginerr cyrusimap_loginerr exim_esmtp_autherr sendmail_relaydenied
  /* for FTP services */
 %s freebsdftpd_loginerr  proftpd_loginerr  pureftpd_loginerr vsftpd_loginerr
 
@@ -109,13 +109,13 @@
   */
 
  /* handle entries with PID and without PID from processes other than sshguard */
-{TIMESTAMP_SYSLOG}[ ]+([a-zA-Z0-9]|{WORD}|{HOSTADDR})[ ]+{PROCESSNAME}"["{NUMBER}"]: "{SOLARIS_MSGID_TAG}? {
+{TIMESTAMP_SYSLOG}[ ]+([a-zA-Z0-9]|{WORD}|{HOSTADDR})[ ]+{PROCESSNAME}("/"{PROCESSNAME})?"["{NUMBER}"]: "{SOLARIS_MSGID_TAG}? {
         /* extract PID */
         yylval.num = getsyslogpid(yytext, yyleng);
         return SYSLOG_BANNER_PID;
         }
 
-{TIMESTAMP_SYSLOG}[ ]+([a-zA-Z0-9]|{WORD}|{HOSTADDR})[ ]+({PROCESSNAME}":")?   { return SYSLOG_BANNER; }
+{TIMESTAMP_SYSLOG}[ ]+([a-zA-Z0-9]|{WORD}|{HOSTADDR})[ ]+({PROCESSNAME}("/"{PROCESSNAME})?":")?   { return SYSLOG_BANNER; }
 
  /* syslog style  "last message repeated N times" */
 "last message repeated "([1-9][0-9]*)" times"                   {
@@ -125,7 +125,7 @@
                                                                 }
 
  /* metalog banner */
-{TIMESTAMP_SYSLOG}" ["{PROCESSNAME}"] "                         { return METALOG_BANNER; }
+{TIMESTAMP_SYSLOG}" ["{PROCESSNAME}("/"{PROCESSNAME})?"] "                         { return METALOG_BANNER; }
 
 
  /* SSH: invalid or rejected user (cross platform [generated by openssh]) */
@@ -172,6 +172,10 @@
 "imap-login: Aborted login (auth failed, "{NUMBER}" attempts): ".+" rip=" { BEGIN(dovecot_loginerr); return DOVECOT_IMAP_LOGINERR_PREF; }
 <dovecot_loginerr>", lip=".+                                        { BEGIN(INITIAL); return DOVECOT_IMAP_LOGINERR_SUFF; }
 
+ /* postfix */
+"warning: "({WORD}|{HOSTADDR})"["                               { BEGIN(postfix_loginerr); return POSTFIX_SASL_LOGINERR_PREF; }
+<postfix_loginerr>"]: SASL "[-A-Z0-9]+" authentication failed".*    { BEGIN(INITIAL); return POSTFIX_SASL_LOGINERR_SUFF; }
+
  /* UWimap login errors */
 "Login failed user="[^ ]+" auth="[^ ]*" host="[^ ]+" "          { return UWIMAP_LOGINERR; }
 
--- src/sshguard_services.h	(revision 238)
+++ src/sshguard_services.h	(working copy)
@@ -62,4 +62,8 @@
 
 /* vsftpd */
 #define SERVICES_VSFTPD                 330
+
+/* postfix */
+#define SERVICES_POSTFIX                340
+
 #endif
